@@ -33,4 +33,4 @@ def tick(carry, x):
 
 @jit
 def tick_buffer(carry, X):
-    return lax.scan(tick, carry, X)[1]
+    return lax.scan(tick, carry, X)
