@@ -13,7 +13,10 @@ def tick_buffer(carry, X):
     state = carry['state']
     params = carry['params']
     Y = X
+    # XXX this quite right. need to clean up `carry` API
     for processor_name in state.keys():
         processor_carry = {'state': state[processor_name]['state'], 'params': params[processor_name]}
-        Y = state[processor_name]['tick_buffer'](processor_carry, Y)
-    return Y
+        processor_carry, Y = state[processor_name]['tick_buffer'](processor_carry, Y)
+        # state[processor_name] = processor_carry['state']
+        # params[processor_name] = processor_carry['params']
+    return carry, Y
